.. Gate Set Tomography documentation master file, created by
   sphinx-quickstart on Thu Jun  4 13:16:14 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyGSTi's documentation
=================================

**pyGSTi** is a python implementation of Gate Set Tomography (GST).

Packages
--------

.. toctree::
   :maxdepth: 2

   autoapi/pygsti/index

License & Copyright
-------------------
.. toctree::
   :maxdepth: 1
   
   LICENSE
   NOTICE

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
